#### Building instructions.
#
### Overview of rebuild options:
#
# --define 'ksrc srcdir' 	: Build with kernel header files found in <srcdir> 
# --define 'kernel kernelver' 	: Build for kernel <kernelver> instead of the current. Might in some cases 
#                                  needed in addition to ksrc or to build for a different fedora-kernel.  
#
### Examples:
#
## To rebuild only kernel modules against currently running fedora kernel 
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" 
#
## To rebuild only kernel modules against currently running kernel where /lib/modules/$(uname -r)/build 
##  points to the build-sources (e.g. self compiled, fedora-kernel without kernel-devel package)
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" --define "ksrc /lib/modules/$(uname -r)/build" 
#
#### End of Building instructions.

%{?ksrc: 	%{!?kernel:    %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && echo "$(cat Makefile 2>/dev/null && echo $'\n'kernelhelper-rel:$'\n'$'\t'@echo \$\(KERNELRELEASE\)$'\n')" 2>/dev/null | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel:             %{expand: %%define kernel %(uname -r)}}


Name:           kernel-module-ntfs
Version:        2.1.27
Release:        1%{?dist}
Summary:        NTFS Kernel Module

Group:          System Environment/Kernel
License:        GPL
URL:            http://www.linux-ntfs.org/
# Created after extracing linux-2.6.17.tar.bz2 and running:
# tar -cvjf ~/rpmbuild/SOURCES/ntfs-2.1.27.tar.bz2 Documentation/filesystems/ntfs.txt COPYING fs/ntfs/
Source0:	ntfs-2.1.27.tar.bz2
Patch0:		CONFIG_NTFS_FS.patch
Patch1:		CONFIG_NTFS_RW.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# needed for buildsys
ExclusiveArch:	i586 i686 x86_64 ppc ppc64

%description
This RPM contains a binary Linux kernel module build from the sources of 
and for %{kernel}. It provides safe read-only NTFS support. 


%package -n kernel-module-ntfs-%{kernel}
Summary:        NTFS Kernel Module
Group:          System Environment/Kernel
Provides:	kernel-module-ntfs
Requires(post):   /sbin/depmod
Requires(postun): /sbin/depmod
%if 0%{!?ksrc:1}
Requires:	 /boot/vmlinuz-%{kernel}
BuildRequires:  kernel-devel-%{_target_cpu} = %{kernel}
%endif

%description -n kernel-module-ntfs-%{kernel}
This RPM contains a binary Linux kernel module build from the sources of 
and for %{kernel}. It provides safe read-only NTFS support. 

%prep
%setup -c -T
if [[ "%{kernel}" = "custom" ]]
then
	(
	set +ex
	echo $'\n'$'\n'"Could not determine your kernel version. You should pass the correct one with"
	echo "the rpmbuild parameter '--define \"kernel <output of uname -r of target kernel>\"'"
	echo "But probably there is something wrong with the ksrc you provided. Therefore the"
	echo "build might fail, too."$'\n'$'\n'
	)
	sleep 10
fi
tar -xjf %{SOURCE0}
cd ./fs/ntfs/
%patch0 -b .patch0
#if 0%{?_with_rw:1}
%patch1 -b .patch1
#endif


%build
make -C "%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}" SUBDIRS=$PWD/fs/ntfs modules


%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/lib/modules/%{kernel}/kernel/fs/ntfs
install -m 755 fs/ntfs/ntfs.ko $RPM_BUILD_ROOT/lib/modules/%{kernel}/kernel/fs/ntfs/


%clean
rm -rf $RPM_BUILD_ROOT


%post -n kernel-module-ntfs-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif


%postun -n kernel-module-ntfs-%{kernel}
%if 0%{!?ksrc:1}
if [ -r /boot/System.map-%{kernel} ] ; then
  /sbin/depmod -e -F /boot/System.map-%{kernel} %{kernel} > /dev/null || :
fi
%else
if [ "$(uname -r)" = "%{kernel}" ] ; then
  /sbin/depmod -a >/dev/null || :
fi
%endif


%files -n kernel-module-ntfs-%{kernel}
%defattr(-,root,root,-)
%doc Documentation/filesystems/ntfs.txt COPYING fs/ntfs/ChangeLog
%dir /lib/modules/%{kernel}/kernel/fs/ntfs
%attr(744,root,root) /lib/modules/%{kernel}/kernel/fs/ntfs/ntfs.ko

%changelog
* Mon Jun 26 2006 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 2.1.27-1
- update to version from 2.6.17
- Use dist
- drop 0.lvn

* Thu Mar 30 2006 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 2.1.26-0.lvn.2
- needed for buildsys: "ExclusiveArch:	i586 i686 x86_64"

* Thu Mar 30 2006 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 2.1.26-0.lvn.1
- Drop epoch
- Update to 2.1.26

* Sun Jan 08 2006 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.25-0.lvn.1
- Update to 2.1.25
- Enable rw by default

* Sat Jun 04 2005 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.22-0.lvn.3
- Adjust to new kmodules scheme -- should work better with FC4

* Sat Jun 04 2005 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.22-0.lvn.2
- Update to Version from 2.6.12 tree
- Adjust BR for FC4
- Include Changelog in %%doc

* Tue Jan 05 2005 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.22-0.lvn.1
- Update to 2.1.22

* Fri Nov 05 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.20-0.lvn.1
- Update to 2.1.20
- Build without kernel-module-devel as default
- BR post, postun /sbin/depmod 

* Sat Oct 16 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.15-0.lvn.9
- Make Build independant of kernel-sourcecode / include sources directly
- Allow building without kernel-module-devel
- Change rhkernel usage again. Use it not for the BR. BR kernel and Co
  always if no srcdir with ksrc provided.
- Allow rpm to strip the kernel module.

* Fri Sep 24 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.15-0.lvn.8
- Can's use fedora-kmodhelper to detect kverrel when it is not installed 
  -> moved kverrel detection to a hardcoded sed command

* Wed Sep 15 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.15-0.lvn.7
- Removed rhkernel detection completely

* Wed Sep 15 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.15-0.lvn.6
- BuildRequire fedora-rpmdevtools

* Wed Sep 15 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.15-0.lvn.5
- rhkernel default
- make srpm uniqe (don't depend on kernel-version)
- remove fedora-kmodhelper
- use kernel-module-devel

* Mon Sep 13 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.15-0.lvn.4
- Fail correctly if kernel is not installed when building for a fedora-kernel
- Re-Do rhkernel-detection workaround

* Sun Sep 12 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.15-0.lvn.3
- Do not fail and warn if a ksrc is not found
- disable rhkernel-detection for the moment  

* Fri Sep 03 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.15-0.lvn.2
- Simple build fix to allow use of kernel-module-devel package

* Sun Aug 29 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.15-0.lvn.1
- Use rhkernel macro so building for custom kernels works
- Buildrequier kernel-sourcecode, kernel-source does not work

* Wed Aug 11 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.14-0.lvn.2
- Use another build approach as suggested by arjanv in 
  129377#c3@bugzilla.redhat.com

* Sun Aug 01 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:2.1.14-0.lvn.1
- Initial RPM release.
